@@ -7,10 +7,10 @@
 #include <jasper/jas_dll.h>
 
 /* This preprocessor symbol identifies the version of JasPer. */
-#define	JAS_VERSION "2.0.27"
+#define	JAS_VERSION "2.0.32"
 #define JAS_VERSION_MAJOR 2
 #define JAS_VERSION_MINOR 0
-#define JAS_VERSION_PATCH 27
+#define JAS_VERSION_PATCH 32
 
 /* #undef JAS_ENABLE_32BIT */
 
@@ -24,7 +24,6 @@
 #define JAS_HAVE_GETTIMEOFDAY 1
 #define JAS_HAVE_GETRUSAGE 1
 
-/* #undef JAS_HAVE_GLUT_GLUT_H */
 /* #undef JAS_HAVE_GL_GLUT_H */
 /* #undef JAS_HAVE_GLUT_H */
 
@@ -33,7 +32,7 @@
 #define JAS_INCLUDE_RAS_CODEC 1
 #define JAS_INCLUDE_JP2_CODEC 1
 #define JAS_INCLUDE_JPC_CODEC 1
-#define JAS_INCLUDE_JPG_CODEC 1
+/* #undef JAS_INCLUDE_JPG_CODEC */
 #define JAS_INCLUDE_PGX_CODEC 1
 #define JAS_INCLUDE_MIF_CODEC 1
 /* #undef JAS_ENABLE_DANGEROUS_INTERNAL_TESTING_MODE */
